# Tcl package index file, version 1.0

set version "3.0"

namespace eval blt${version} {}

proc blt${version}::load_library { name version dir package } {

    set prefix "lib"
    set suffix ""
    set so [info sharedlibextension]
    regsub {\.} $version {} version_no_dots

    set fullname ${prefix}${name}${version_no_dots}${suffix}${so}

    global tcl_platform
    if { $tcl_platform(platform) == "unix" } {
	set library [file join $dir $fullname]
	if { ![file exists $library] } {
	    # Try the parent directory.
	    set library [file join [file dirname $dir] $fullname]
	}
	if { ![file exists $library] } {
	    # Default to the path generated at compilation.
	    set library [file join "/build/buildd/saods9-6.2+dfsg/lib" $fullname]
	}
    } else {
	set library $fullname
    }
    load $library $package
}

package ifneeded BLT $version [subst -nocommands {
    package require blt_core $version
    if { [info commands tk] == "tk" } {
	package require blt_extra $version
    } 
    package provide BLT $version
}]

# Core (tcl-only) and extra (Tk) packages 

package ifneeded blt_core $version \
    [list blt${version}::load_library "BLTCore" $version $dir "blt_core"]

package ifneeded blt_extra $version [subst {
    package require blt_core
    blt${version}::load_library "BLTX" $version $dir "blt_x"
}]

# Data table data format packages

package ifneeded blt_datatable_xml $version [subst {
    package require blt_core
    blt::datatable load xml $dir
}]

package ifneeded blt_datatable_mysql $version \
	[list blt::datatable load mysql $dir]

package ifneeded blt_datatable_tree $version \
	[list blt::datatable load tree $dir]

package ifneeded blt_datatable_vector $version \
	[list blt::datatable load vector $dir]

package ifneeded blt_datatable_csv $version \
	[list blt::datatable load csv $dir]

# Picture image format packages

package ifneeded blt_picture_bmp $version [subst {
    package require BLT
    blt::picture load bmp $dir
}]

package ifneeded blt_picture_gif $version \
	[list blt::picture load gif $dir]

package ifneeded blt_picture_jpg $version \
	[list blt::picture load jpg $dir]

package ifneeded blt_picture_pbm $version \
	[list blt::picture load pbm $dir]

package ifneeded blt_picture_png $version \
	[list blt::picture load png $dir]

package ifneeded blt_picture_ps $version \
	[list blt::picture load ps $dir]

package ifneeded blt_picture_tif $version \
	[list blt::picture load tif $dir]

package ifneeded blt_picture_xbm $version \
	[list blt::picture load xbm $dir]

package ifneeded blt_picture_xpm $version \
	[list blt::picture load xpm $dir]

package ifneeded blt_picture_photo $version \
	[list blt::picture load photo $dir]

# Tree data format packages

package ifneeded blt_tree_xml $version \
	[list blt::tree load xml $dir]

# End of package index file
